Class: MiniCli::Base
- Inherits:
-
Thor
- Object
- Thor
- MiniCli::Base
- Includes:
- BaseModule
- Defined in:
- lib/mini_cli/base.rb
Overview
The base class to inherit from to provide the basic commands of a microservice
The base class to inherit from to provide the basic commands of a microservice